summaryrefslogtreecommitdiff
path: root/source/slang/slang-emit-spirv.cpp
diff options
context:
space:
mode:
authorEllie Hermaszewska <ellieh@nvidia.com>2023-02-03 12:18:49 +0800
committerGitHub <noreply@github.com>2023-02-03 12:18:49 +0800
commita00dc69ca8dfbc346940c7d03d67c1cb229577fb (patch)
treece102791bfe2b052edb4e4fc3453a92fc53fb3a8 /source/slang/slang-emit-spirv.cpp
parentbbd1e1786401bb88c34802b987d4da72e2364503 (diff)
Use SPIR-V opcode names rather than numbers (#2571)
* s/emititng blobal/emitting global * Use SPIR-V opcode names rather than numbers * regenerate Visual Studio project files * Use names for extended SPIR-V GLSL instructions * Add missing operand for SPIR-V extended instruction * Add warning aginst modifying generated hashing files * Squash warnings on MSVC
Diffstat (limited to 'source/slang/slang-emit-spirv.cpp')
-rw-r--r--source/slang/slang-emit-spirv.cpp7
1 files changed, 4 insertions, 3 deletions
diff --git a/source/slang/slang-emit-spirv.cpp b/source/slang/slang-emit-spirv.cpp
index 09ad3be58..47537b108 100644
--- a/source/slang/slang-emit-spirv.cpp
+++ b/source/slang/slang-emit-spirv.cpp
@@ -915,6 +915,7 @@ struct SPIRVEmitContext
getSection(SpvLogicalSectionID::ExtIntInstImports),
nullptr,
SpvOpExtInstImport,
+ kResultID,
UnownedStringSlice("GLSL.std.450"));
return m_glsl450ExtInst;
}
@@ -1213,7 +1214,7 @@ struct SPIRVEmitContext
// ...
default:
- SLANG_UNIMPLEMENTED_X("unhandled instruction opcode");
+ SLANG_UNIMPLEMENTED_X("unhandled instruction opcode for global instruction");
UNREACHABLE_RETURN(nullptr);
}
}
@@ -1568,7 +1569,7 @@ struct SPIRVEmitContext
// The instructions that appear inside the basic blocks of
// functions are what we will call "local" instructions.
//
// When emititng blobal instructions, we usually have to
// pick the right logical section to emit them into, while
// for local instructions they will usually emit into
// a known parent (the basic block that contains them).
@@ -1579,7 +1580,7 @@ struct SPIRVEmitContext
switch( inst->getOp() )
{
default:
- SLANG_UNIMPLEMENTED_X("unhandled instruction opcode");
+ SLANG_UNIMPLEMENTED_X("unhandled instruction opcode for local instruction");
break;
case kIROp_Specialize:
return nullptr;
@@ -1568,7 +1569,7 @@ struct SPIRVEmitContext
// functions are what we will call "local" instructions.
//
- // When emititng blobal instructions, we usually have to
+ // When emitting global instructions, we usually have to
// pick the right logical section to emit them into, while
// for local instructions they will usually emit into